@@ -92,7 +92,7 @@ frdAllPairsMillerTest.default <-
         blocks <- factor(blocks)
         k <- nlevels(groups)
         n <- nlevels(blocks)
-        GRPNAMES <- as.character(groups[1:k])
+        GRPNAMES <- levels(groups)
     }
 
     mat <- matrix(y, nrow = n, ncol = k, byrow = TRUE)
